Does string contain the specified file type or any file extension?
Source:R/has_filetype.R
has_fileext.RdCheck if string contains any filetype or the provided filetype. If string is
NULL, returns FALSE.
R/has_filetype.R
has_fileext.RdCheck if string contains any filetype or the provided filetype. If string is
NULL, returns FALSE.